@@ -1,5 +1,6 @@
 #[derive(PartialEq, Debug)]
 pub enum NodeType {
     Program,
-    Identity
+    Identity,
+    ObjectIdentifierIndex
 }
\ No newline at end of file
